/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.math;

import com.vividsolutions.jts.geom.Coordinate;

/**
 * Implementations of this interface interpolate coordinates
 * a line at a given point determined by a factor t (0 &lt;= t &lt;= 1).<br>
 * If t = 0 the start point of the line is used.<br>
 * If t = 1 the start point of the line is used.
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public interface Interpolator
{
    /**
     * Interpolates a point along a line with a given factor between 0 and 1.
     * @param t The factor.
     * @param v The result of the interpolation is stored in this coordinate.
     */
    void interpolate(double t, Coordinate v);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
